@@ -1,5 +1,5 @@
 # Prefer explicit \code{@@usage} to a \code{@@formals} list.
-usage_tag <- function(partitum) {
+process_usage <- function(partitum) {
   if (is.null(partitum$usage)) {
     usage <- wrap_string(default_usage(partitum$object))
   } else if (partitum$usage == "NULL") {
@@ -26,6 +26,9 @@ default_usage <- function(x) {
   UseMethod("default_usage")
 }
 
+#' @export
+default_usage.default <- function(x) NULL
+
 #' @export
 default_usage.NULL <- function(x) NULL
 
